@@ -40,7 +40,6 @@ class StreamApp(object):
         consumer_id = generate()
         group_name = self.current_actor_name
         while True:
-            print("死循环")
             consumer = RedisConsumer(self.redis_client, group_name, stream_names_imput_map.keys())
             msgs = consumer.consume(consumer_id, 1)
             # 如果消息为空，判断上游所有算子状态是否结束
@@ -305,7 +304,6 @@ class StreamApp(object):
         if isinstance(self.actor, SourceActor):
             self.process_source_actor(self.actor)
         elif isinstance(self.actor, SinkActor):
-            print('-----sink算子')
             self.process_sink_actor(self.actor, input_ports)
         # 处理其他Actor(Compute Actor)
         else:
