@@ -11,11 +11,9 @@ ACTOR_STATE_RUNNING = "RUNNING"
 #(定时任务)根据slurm的scontrol命令来判断timer.update_actor_state()
 ACTOR_STATE_SUCCESS = "SUCCESS"
 ACTOR_STATE_FAILED = "FAILED"
+ACTOR_STATE_CANCELLED = "CANCELLED"
 ACTOR_STATE_STOPPABLE = "STOPPABLE"
 
-#----slurm的状态----
-SLURM_STATE_COMPLATED = "COMPLATED"
-SLURM_STATE_RUNNING = "RUNNING"
 # redis key
 # 算子间的关系
 REDIS_KEY_FOR_ACTOR_RELATION = 'flow_manager_for_actor_relation'
@@ -24,4 +22,4 @@ REDIS_KEY_FOR_ACTOR_STATE = 'flow_manager_for_actor_state'
 # 算子的整体状态
 REDIS_KEY_FOR_ACTOR_FINAL_STATE = 'flow_manager_for_actor_final_state'
 # # jobId和算子间的关系
-# REDIS_KEY_FOR_JOB_MAPPING = 'flow_mananger_for_job_mapping'
\ No newline at end of file
+# REDIS_KEY_FOR_JOB_MAPPING = 'flow_manager_for_job_mapping'
\ No newline at end of file
